@@ -273,7 +273,7 @@ int main(int argc, char** argv) {
 
   // read index file
   if ( ! inBam.ReadBamIndex( sIndexFile.c_str() ) ) {
-    Logger::gLogger->error("Cannot open BAM file index %s for reading - %s", sIndexFile.c_str());
+    Logger::gLogger->error("Cannot open BAM file index %s for reading %s", sIndexFile.c_str(),sInFile.c_str());
   }
 
   Logger::gLogger->writeLog("Reading header Records");
@@ -447,7 +447,7 @@ int main(int argc, char** argv) {
 	sIndexFile = sInFile + ".bai";
 
 	if ( ! inBam.ReadBamIndex( sIndexFile.c_str() ) ) {
-	  Logger::gLogger->error("Cannot open BAM file index %s for reading - %s", sIndexFile.c_str());	
+	  Logger::gLogger->error("Cannot open BAM file index %s for reading %s", sIndexFile.c_str(),sInFile.c_str());
 	}
 	
 	for( uint32_t k=0, rgCnt = 0; (pSamHeaderRecord = inHeader.getNextHeaderRecord()) != NULL; ++k ) {
